@@ -8,6 +8,7 @@ from copy import deepcopy
 from .revision import ModelRevision
 from .jobDefinitions import JOB_DEFINITIONS
 from ..utils import request, fileLoad, graphql_request
+from ..verify import userName
 
 
 class Model(object):
@@ -38,7 +39,7 @@ class Model(object):
         for k, v in model.items():
             if k == 'revision':
                 if 'version' in v and v['version'] == 3:
-                    self.__dict__[k] = ModelRevision(v)
+                    self.revision = ModelRevision(v)
                 else:
                     raise Exception(
                         '当前SDK版本（ver 3.X.X）不兼容该项目文件，请先升级项目文件。具体方法：将该项目文件导入至XStudio 3.X.X平台后重新保存至本地后即可。'
@@ -369,14 +370,14 @@ class Model(object):
                 model.save(model,'newKey') # 另存为新的项目
 
         """
-        username = os.environ.get('USER_NAME')
+        username = userName()
 
         if key is not None:
             matchObj = re.match(r'^[-_A-Za-z0-9]+$', key, re.I | re.S)
             if matchObj:
                 self.rid = 'model/' + username + '/' + key
                 try:
-                    r = request('GET', 'resources/' + self.rid)
+                    r = request('GET', 'api/resources/' + self.rid)
                     return Model.update(self)
                 except:
                     return Model.create(self)
@@ -390,7 +391,7 @@ class Model(object):
             elif owner[0] != username:
                 rid = re.sub(t, username, self.rid)
                 try:
-                    r = request('GET', 'resources/' + self.rid)
+                    r = request('GET', 'api/resources/' + self.rid)
                     return Model.create(self)
                 except:
                     raise Exception(rid + ' 该资源已存在，无法重复创建,请修改 key')
@@ -411,7 +412,7 @@ class Model(object):
         """
         # Model.update(model)
         t = '(?<=/)\\S+(?=/)'
-        username = os.environ.get('USER_NAME')
+        username = userName()
         owner = re.search(t, model.rid)
 
         if owner is None:
@@ -462,7 +463,7 @@ class Model(object):
         """
 
         t = '(?<=/)\\S+(?=/)'
-        username = os.environ.get('USER_NAME')
+        username = userName()
         owner = re.search(t, model.rid)
 
         if owner is None:
