@@ -26,7 +26,7 @@ class Runner(object):
 
         self.taskId = taskId
         self.db = Storage(taskId, name, job, config, revision, modelRid)
-        result = RESULT_DB.get(job['rid'], EMTResult)
+        result = RESULT_DB.get(job['rid'], Result)
         self.result = result(self.db)
         self.receiver = None
 
@@ -60,6 +60,13 @@ class Runner(object):
         self.receiver = receiver(self.taskId, self.db, **kwargs)
         self.receiver.connect()
 
+    def terminate(self):
+        """
+        结束当前运行的算例
+
+        """
+        r = request("DELETE", 'api/simulation/runner/' + str(self.taskId))
+
     @staticmethod
     def create(revisionHash, job, config, name=None, rid='', **kwargs):
         '''
@@ -88,7 +95,7 @@ class Runner(object):
             'implement': kwargs.get('topology', None)
         }
         while not runner.__listenStatus():
-            time.sleep(1)
+            time.sleep(0.1)
         r = request('POST',
                     'api/simulation/runner/' + revisionHash + '/' +
                     str(taskId),
