@@ -19,13 +19,16 @@ def request(method, uri, baseUrl=None, params={}, token=None, **kwargs):
     else:
         raise Exception('token undefined')
     r = requests.request(method, url, params=params, headers=headers, **kwargs)
-    if 'X-Cloudpss-Version' not in r.headers:
-        raise Exception(
-            '当前SDK版本（ver 3.X.X）与服务器版本（3.0.0 以下）不兼容，请更换服务器地址或更换SDK版本。')
-    if r.headers['X-Cloudpss-Version'] != '3':
-        raise Exception('当前SDK版本（ver 3.X.X）与服务器版本（ver ' +
-                        r.headers['X-Cloudpss-Version'] +
-                        '.X.X）不兼容，请更换服务器地址或更换SDK版本。')
+
+    if (uri.startswith('graphql')):
+        if 'X-Cloudpss-Version' not in r.headers:
+            raise Exception(
+                '当前SDK版本（ver 3.X.X）与服务器版本（3.0.0 以下）不兼容，请更换服务器地址或更换SDK版本。')
+        if float(r.headers['X-Cloudpss-Version']) < 3 and float(
+                r.headers['X-Cloudpss-Version']) > 4:
+            raise Exception('当前SDK版本（ver 3.X.X）与服务器版本（ver ' +
+                            r.headers['X-Cloudpss-Version'] +
+                            '.X.X）不兼容，请更换服务器地址或更换SDK版本。')
 
     try:
         r.raise_for_status()
